"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TRenderEngine = void 0;

var _collapse = require("./flow/collapse");

var _hoist = require("./flow/hoist");

var _translate = require("./flow/translate");

var _htmlparser = require("htmlparser2");

var _cssProcessor = require("@native-html/css-processor");

var _TStylesMerger = require("./styles/TStylesMerger");

var _defaults = require("./styles/defaults");

var _TStyles = require("./styles/TStyles");

var _HTMLModelRegistry = _interopRequireDefault(require("./model/HTMLModelRegistry"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class TRenderEngine {
  constructor(options) {
    var _options$stylesConfig, _options$cssProcessor;

    _defineProperty(this, "htmlParserOptions", void 0);

    _defineProperty(this, "dataFlowParams", void 0);

    const baseStyle = { ..._defaults.defaultStylesConfig.baseStyle,
      ...(options === null || options === void 0 ? void 0 : (_options$stylesConfig = options.stylesConfig) === null || _options$stylesConfig === void 0 ? void 0 : _options$stylesConfig.baseStyle)
    };
    const modelRegistry = new _HTMLModelRegistry.default(options === null || options === void 0 ? void 0 : options.customizeHTMLModels);
    const userSelectedFontSize = (options === null || options === void 0 ? void 0 : (_options$cssProcessor = options.cssProcessorConfig) === null || _options$cssProcessor === void 0 ? void 0 : _options$cssProcessor.rootFontSize) || baseStyle.fontSize; // TODO log a warning when type is string

    const rootFontSize = typeof userSelectedFontSize === 'number' ? userSelectedFontSize : 14;
    baseStyle.fontSize = rootFontSize;
    const stylesConfig = { ..._defaults.defaultStylesConfig,
      ...(options === null || options === void 0 ? void 0 : options.stylesConfig),
      baseStyle
    };
    const stylesMerger = new _TStylesMerger.TStylesMerger(stylesConfig, modelRegistry, { ..._cssProcessor.defaultCSSProcessorConfig,
      ...(options === null || options === void 0 ? void 0 : options.cssProcessorConfig),
      rootFontSize
    });
    this.htmlParserOptions = {
      decodeEntities: true,
      ...(options === null || options === void 0 ? void 0 : options.htmlParserOptions)
    };
    this.dataFlowParams = {
      stylesMerger,
      modelRegistry,
      baseStyles: new _TStyles.TStyles(stylesMerger.compileStyleDeclaration(stylesConfig.baseStyle))
    };
  }

  buildTTree(html) {
    const documentTree = (0, _htmlparser.parseDOM)(html, this.htmlParserOptions);
    const tdoc = (0, _translate.translateDocument)(documentTree, this.dataFlowParams);
    return (0, _collapse.collapse)((0, _hoist.hoist)(tdoc));
  }

}

exports.TRenderEngine = TRenderEngine;
//# sourceMappingURL=TRenderEngine.js.map