"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _HTMLContentModel = _interopRequireDefault(require("./HTMLContentModel"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const phrasingCategories = ['textual', 'edits', 'anchor'];
const translatableBlockCategories = ['embedded', 'tabular', 'grouping', 'sectioning'];

class HTMLElementModel {
  constructor({
    tagName,
    contentModel,
    isTranslatable,
    isOpaque,
    isVoid,
    mixedUAStyles,
    getUADerivedStyleFromAttributes
  }) {
    _defineProperty(this, "tagName", void 0);

    _defineProperty(this, "contentModel", void 0);

    _defineProperty(this, "isTranslatable", void 0);

    _defineProperty(this, "isOpaque", void 0);

    _defineProperty(this, "isVoid", void 0);

    _defineProperty(this, "mixedUAStyles", void 0);

    _defineProperty(this, "getUADerivedStyleFromAttributes", void 0);

    this.tagName = tagName;
    this.contentModel = contentModel;
    this.isTranslatable = isTranslatable;
    this.isOpaque = isOpaque;
    this.isVoid = isVoid;
    this.mixedUAStyles = mixedUAStyles;
    this.getUADerivedStyleFromAttributes = getUADerivedStyleFromAttributes;
  }

  static fromCustomModel({
    contentModel,
    tagName,
    isOpaque = false,
    ...optionalFields
  }) {
    return new HTMLElementModel({
      tagName,
      contentModel,
      isOpaque,
      isTranslatable: true,
      isVoid: false,
      ...optionalFields
    });
  }

  static fromNativeModel({
    tagName,
    category,
    isOpaque,
    isVoid,
    mixedUAStyles,
    getUADerivedStyleFromAttributes
  }) {
    const isPhrasing = phrasingCategories.indexOf(category) !== -1;
    const contentModel = category === 'anchor' ? _HTMLContentModel.default.mixed : isPhrasing ? _HTMLContentModel.default.textual : _HTMLContentModel.default.block;
    const isTranslatable = contentModel !== _HTMLContentModel.default.block || translatableBlockCategories.indexOf(category) !== -1;
    return new HTMLElementModel({
      tagName,
      contentModel,
      isTranslatable,
      isVoid: isVoid || false,
      mixedUAStyles,
      isOpaque: isOpaque !== null && isOpaque !== void 0 ? isOpaque : category === 'embedded',
      getUADerivedStyleFromAttributes
    });
  }

  isTranslatableBlock() {
    return this.isTranslatable && this.contentModel === _HTMLContentModel.default.block;
  }

  isTranslatableTextual() {
    return this.contentModel === _HTMLContentModel.default.textual || this.contentModel === _HTMLContentModel.default.mixed;
  }

  extend(props) {
    return new HTMLElementModel({ ...this,
      ...props
    });
  }

  getUADerivedCSSProcessedPropsFromAttributes(attributes) {
    if (this.getUADerivedStyleFromAttributes) {
      return this.getUADerivedStyleFromAttributes(attributes);
    }

    return null;
  }

}

exports.default = HTMLElementModel;
//# sourceMappingURL=HTMLElementModel.js.map