import { TDocument } from './tree/TDocument';
import { ParserOptions as HTMLParserOptions } from 'htmlparser2';
import { CSSProcessorConfig } from '@native-html/css-processor';
import { StylesConfig } from './styles/types';
import { HTMLModelRecord, TagName } from './model/model-types';
export interface TRenderEngineOptions<E extends string = never> {
    /**
     * Customization for CSS inline processing.
     */
    readonly cssProcessorConfig?: Partial<CSSProcessorConfig>;
    /**
     * Options for htmlparser2 library parser.
     */
    readonly htmlParserOptions?: Readonly<HTMLParserOptions>;
    /**
     * Various configuration for styling.
     */
    readonly stylesConfig?: StylesConfig;
    /**
     * Customize supported tags in the engine.
     *
     * @remarks If you need to add new tags, always use lowercase names.
     */
    readonly customizeHTMLModels?: (defaultModelRecord: HTMLModelRecord<TagName>) => HTMLModelRecord<TagName | E>;
}
export declare class TRenderEngine {
    private htmlParserOptions;
    private dataFlowParams;
    constructor(options?: TRenderEngineOptions);
    buildTTree(html: string): TDocument;
}
