import { MixedStyleDeclaration } from '@native-html/css-processor';
import HTMLContentModel from './HTMLContentModel';
import { CustomElementModel, ElementCategory, NativeElementModel, TagName } from './model-types';
export interface HTMLElementModelProperties<T extends string> {
    readonly tagName: T;
    readonly contentModel: HTMLContentModel;
    readonly isTranslatable: boolean;
    readonly isOpaque: boolean;
    readonly isVoid: boolean;
    readonly mixedUAStyles?: MixedStyleDeclaration;
    /**
     * For example, "width" and "height" attributes for &lt;img&gt; tags.
     */
    readonly getUADerivedStyleFromAttributes?: (attributes: Record<string, string>) => MixedStyleDeclaration | null;
}
export default class HTMLElementModel<T extends string> implements HTMLElementModelProperties<T> {
    readonly tagName: T;
    readonly contentModel: HTMLContentModel;
    readonly isTranslatable: boolean;
    readonly isOpaque: boolean;
    readonly isVoid: boolean;
    readonly mixedUAStyles?: MixedStyleDeclaration;
    readonly getUADerivedStyleFromAttributes: NativeElementModel['getUADerivedStyleFromAttributes'];
    private constructor();
    static fromCustomModel<T extends string>({ contentModel, tagName, isOpaque, ...optionalFields }: CustomElementModel<T>): HTMLElementModel<Exclude<T, TagName>>;
    static fromNativeModel<T extends TagName>({ tagName, category, isOpaque, isVoid, mixedUAStyles, getUADerivedStyleFromAttributes }: NativeElementModel<T, ElementCategory>): HTMLElementModel<T>;
    isTranslatableBlock(): boolean;
    isTranslatableTextual(): boolean;
    extend(props: Partial<HTMLElementModelProperties<T>>): HTMLElementModel<T>;
    getUADerivedCSSProcessedPropsFromAttributes(attributes: Record<string, string>): MixedStyleDeclaration | null;
}
